@@ -21,7 +21,7 @@
 
 class K3bCddbOptionTab : public base_K3bCddbOptionTab
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
